@@ -10,21 +10,28 @@ function(x, maxpixels, ...) {
 	if (! missing(maxpixels)) {
 		x <- sampleRegular(x, maxpixels, asRaster=TRUE)
 	}
-	x <- array(as.matrix(x), c(dim(x), 1))
+	x <- array(as.matrix(x), c(dim(x)))
 	x
 } )
 
-setMethod('as.array', signature(x='Raster'), 
-function(x, maxpixels, ...) {
+setMethod('as.array', signature(x='RasterStackBrick'), 
+function(x, maxpixels, transpose=FALSE) {
 	if (!hasValues(x)) { stop("'x' has no values") }
 	if (! missing(maxpixels)) {
 		x <- sampleRegular(x, maxpixels, asRaster=TRUE)
 	}
 	dm <- dim(x)
-	ar <- array(NA, dm)
 	x <- getValues(x)
-	for (i in 1:dm[3]) {
-		ar[,,i] <- matrix(x[,i], nrow=dm[1])
+	if (transpose) {
+		ar <- array(NA, c(dm[2], dm[1], dm[3]))
+		for (i in 1:dm[3]) {
+			ar[,,i] <- matrix(x[,i], nrow=dm[2], byrow=FALSE)
+		}	
+	} else {
+		ar <- array(NA, dm)
+		for (i in 1:dm[3]) {
+			ar[,,i] <- matrix(x[,i], nrow=dm[1], byrow=TRUE)
+		}
 	}
 	ar
 } )
