@@ -12,7 +12,7 @@ if (!isGeneric("distance")) {
 setMethod('distance', signature(x='RasterLayer'), 
 function(x, filename='', doEdge=TRUE, ...) {
 	if (doEdge) {
-		r <- edge(x, classes=FALSE, type='inner', progress=.progress(...)) 
+		r <- raster::edge(x, classes=FALSE, type='inner', progress=.progress(...)) 
 		pts <- try(  rasterToPoints(r, fun=function(z){ z>0 } )[,1:2, drop=FALSE] )
 	} else {
 		pts <- try(  rasterToPoints(x)[,1:2, drop=FALSE] )
@@ -34,7 +34,7 @@ function(x, filename='', doEdge=TRUE, ...) {
 	}
 	                                                                        
 	if (canProcessInMemory(out, 6)) {
-		pb <- pbCreate(3, ...)
+		pb <- pbCreate(3, label='distance', ...)
 		x <- values(x)
 		i <- which(is.na(x))
 		if (length(i) < 1) {
@@ -56,7 +56,7 @@ function(x, filename='', doEdge=TRUE, ...) {
 	
 	out <- writeStart(out, filename=filename, ...)
 	tr <- blockSize(out)
-	pb <- pbCreate(tr$n, ...)
+	pb <- pbCreate(tr$n, label='distance', ...)
 	xy <- cbind(rep(xFromCol(out, 1:ncol(out)), tr$nrows[1]), NA)
 	for (i in 1:tr$n) {
 		if (i == tr$n) {
