@@ -15,6 +15,13 @@ function(x) {
 	r <- res(x)
 	x <- e@xmin - r[1]*(round(e@xmin / r[1]))
 	y <- e@ymax - r[2]*(round(e@ymax / r[2]))
+	
+	if (isTRUE(all.equal((r[1] + x), abs(x)))) {
+		x <- abs(x)
+	}
+	if (isTRUE(all.equal((r[2] + y), abs(y)))) {
+		y <- abs(y)
+	}
 	return(c(x, y))
 }
 )
